AppRouterDelegate class
- Inheritance
-
- Mixed-in types
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
build(BuildContext context)
→ Widget
-
Called by the Router to obtain the widget tree that represents the
current state.
override
-
canPop()
→ bool
-
Whether the navigator can be popped.
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
findOldRoutePage<T extends Object?>(RoutePage<T?> page)
→ RoutePage<T?>?
-
-
getCurrentWidget()
→ Widget?
-
-
getPath(Widget child)
→ String
-
-
handleBackPressed()
→ Future<bool>
-
-
isExist(Widget child)
→ bool
-
-
mayBePop<T extends Object?>([T? result])
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pop<T extends Object?>([T? result])
→ void
-
-
popAndPushWidget<T extends Object?>(Widget routeWidget, {T? result, Map<String, dynamic>? arguments, PageParameter? pageParameter})
→ Future<T?>
-
-
popRoute()
→ Future<bool>
-
Called by the Router when the Router.backButtonDispatcher reports that
the operating system is requesting that the current route be popped.
override
-
popUntil(PagePredicate predicate)
→ void
-
Calls pop repeatedly on the navigator that most tightly encloses the
given context until the predicate returns true.
-
popUntilAndPushWidget<T extends Object?>(PagePredicate predicate, Widget routeWidget, {Map<String, dynamic>? arguments, PageParameter? pageParameter})
→ Future<T?>
-
-
push<T extends Object?>(Widget routeWidget, {Map<String, dynamic>? arguments, PageParameter? pageParameter})
→ Future<T?>
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setInitialRoutePath(PageConfiguration configuration)
→ Future<void>
-
Called by the Router at startup with the structure that the
RouteInformationParser obtained from parsing the initial route.
inherited
-
setNewRoutePath(PageConfiguration configuration)
→ Future<void>
-
Called by the Router when the Router.routeInformationProvider reports that a
new route has been pushed to the application by the operating system.
override
-
setPages(List<RoutePage> newPages)
→ void
-
-
setRestoredRoutePath(PageConfiguration configuration)
→ Future<void>
-
Called by the Router during state restoration.
inherited
-
setRootWidget(Widget rootWidget)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateWidgetIfNeed<T>(RoutePage<T?> page, {Widget? updatedWidget})
→ Widget?
-